@@ -27,7 +27,7 @@ from IPython.core.getipython import get_ipython
 
 from spyder_kernels.comms.frontendcomm import CommError, frontend_request
 from spyder_kernels.customize.namespace_manager import NamespaceManager
-from spyder_kernels.customize.spyderpdb import SpyderPdb
+from spyder_kernels.customize.spyderpdb import SpyderPdb, enter_debugger
 from spyder_kernels.customize.umr import UserModuleReloader
 from spyder_kernels.py3compat import TimeoutError, PY2, _print, encode
 
@@ -109,6 +109,7 @@ if os.name == 'nt' and HIDE_CMD_WINDOWS:
 
     subprocess.Popen = SubprocessPopen
 
+
 # =============================================================================
 # Importing user's sitecustomize
 # =============================================================================
@@ -185,6 +186,7 @@ try:
 except Exception:
     pass
 
+
 # =============================================================================
 # IPython adjustments
 # =============================================================================
@@ -311,6 +313,16 @@ if not PY2:
         pass
 
 
+# =============================================================================
+# os adjustments
+# =============================================================================
+# This is necessary to have better support for Rich and Colorama.
+def _patched_get_terminal_size(fd=None):
+    return os.terminal_size((80, 30))
+
+os.get_terminal_size = _patched_get_terminal_size
+
+
 # =============================================================================
 # Pdb adjustments
 # =============================================================================
@@ -374,18 +386,6 @@ def get_current_file_name():
         return None
 
 
-def get_debugger(filename):
-    """Get a debugger for a given filename."""
-    debugger = pdb.Pdb()
-    filename = debugger.canonic(filename)
-    debugger._wait_for_mainpyfile = 1
-    debugger.mainpyfile = filename
-    debugger._user_requested_quit = 0
-    if os.name == 'nt':
-        filename = filename.replace('\\', '/')
-    return debugger, filename
-
-
 def count_leading_empty_lines(cell):
     """Count the number of leading empty cells."""
     if PY2:
@@ -597,10 +597,12 @@ def debugfile(filename=None, args=None, wdir=None, post_mortem=False,
         filename = get_current_file_name()
         if filename is None:
             return
-    debugger, filename = get_debugger(filename)
-    debugger.continue_if_has_breakpoints = True
-    debugger.run("runfile(%r, args=%r, wdir=%r, current_namespace=%r)" % (
-        filename, args, wdir, current_namespace))
+
+    enter_debugger(
+        filename, True,
+        "runfile({}" +
+        ", args=%r, wdir=%r, current_namespace=%r)" % (
+            args, wdir, current_namespace))
 
 
 builtins.debugfile = debugfile
@@ -678,11 +680,10 @@ def debugcell(cellname, filename=None, post_mortem=False):
         if filename is None:
             return
 
-    debugger, filename = get_debugger(filename)
-    # The breakpoint might not be in the cell
-    debugger.continue_if_has_breakpoints = False
-    debugger.run("runcell({}, {})".format(
-        repr(cellname), repr(filename)))
+    enter_debugger(
+        filename, False,
+        "runcell({}, ".format(repr(cellname)) +
+        "{})")
 
 
 builtins.debugcell = debugcell
